[Bf-blender-cvs] SVN commit: /data/svn/bf-blender [61363] trunk/lib/win64_vc12/opensubdiv: Update OpenSubdiv 64bit, msvc2013

Sergey Sharybin sergey.vfx at gmail.com
Fri May 30 21:44:03 CEST 2014


Revision: 61363
          https://developer.blender.org/rBL61363
Author:   sergey
Date:     2014-05-30 19:44:03 +0000 (Fri, 30 May 2014)
Log Message:
-----------
Update OpenSubdiv 64bit, msvc2013

Now it includes OpenCL and CUDA which are loaded
dynamically on runtime.

Modified Paths:
--------------
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/catmarkSubdivisionTablesFactory.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/loopSubdivisionTablesFactory.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/meshFactory.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/patchMap.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/patchParam.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/patchTables.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/patchTablesFactory.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/stencilTables.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/stencilTablesFactory.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/vertexEditTablesFactory.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/hbr/fvarData.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/hbr/halfedge.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/hbr/loop.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/osd/cpuComputeContext.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/osd/cpuEvalLimitController.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/osd/cpuEvalStencilsContext.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/osd/cpuSmoothNormalContext.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/osd/drawContext.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/osd/error.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/osd/evalLimitContext.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/osd/glDrawRegistry.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/osd/glMesh.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/osd/opengl.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/osd/vertex.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/osdutil/patchPartitioner.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/version.h
    trunk/lib/win64_vc12/opensubdiv/lib/osdCPU.lib
    trunk/lib/win64_vc12/opensubdiv/lib/osdCPU_d.lib
    trunk/lib/win64_vc12/opensubdiv/lib/osdGPU.lib
    trunk/lib/win64_vc12/opensubdiv/lib/osdGPU_d.lib
    trunk/lib/win64_vc12/opensubdiv/lib/osdutil.lib
    trunk/lib/win64_vc12/opensubdiv/lib/osdutil_d.lib
    trunk/lib/win64_vc12/opensubdiv/readme.txt

Added Paths:
-----------
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/osd/clComputeContext.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/osd/clComputeController.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/osd/clGLVertexBuffer.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/osd/clVertexBuffer.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/osd/cuda.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/osd/cudaComputeContext.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/osd/cudaComputeController.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/osd/cudaGLVertexBuffer.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/osd/cudaVertexBuffer.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/osd/opencl.h
    trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/osdutil/batchCL.h

Modified: trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/catmarkSubdivisionTablesFactory.h
===================================================================
--- trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/catmarkSubdivisionTablesFactory.h	2014-05-20 21:24:22 UTC (rev 61362)
+++ trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/catmarkSubdivisionTablesFactory.h	2014-05-30 19:44:03 UTC (rev 61363)
@@ -284,7 +284,7 @@
                         public:
                             HbrVertex<T> * vertex; int eidx[2]; int count; bool next;
 
-                            GatherCreaseEdgesOperator(HbrVertex<T> * v, bool n) : vertex(v), count(0), next(n) { eidx[0]=-1; eidx[1]=-1; }
+                            GatherCreaseEdgesOperator(HbrVertex<T> * vtx, bool n) : vertex(vtx), count(0), next(n) { eidx[0]=-1; eidx[1]=-1; }
 
                             ~GatherCreaseEdgesOperator() { }
 

Modified: trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/loopSubdivisionTablesFactory.h
===================================================================
--- trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/loopSubdivisionTablesFactory.h	2014-05-20 21:24:22 UTC (rev 61362)
+++ trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/loopSubdivisionTablesFactory.h	2014-05-30 19:44:03 UTC (rev 61363)
@@ -216,7 +216,7 @@
                         public:
                             HbrVertex<T> * vertex; int eidx[2]; int count; bool next;
 
-                            GatherCreaseEdgesOperator(HbrVertex<T> * v, bool n) : vertex(v), count(0), next(n) { eidx[0]=-1; eidx[1]=-1; }
+                            GatherCreaseEdgesOperator(HbrVertex<T> * vtx, bool n) : vertex(vtx), count(0), next(n) { eidx[0]=-1; eidx[1]=-1; }
 
                             ~GatherCreaseEdgesOperator() { }
 

Modified: trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/meshFactory.h
===================================================================
--- trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/meshFactory.h	2014-05-20 21:24:22 UTC (rev 61362)
+++ trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/meshFactory.h	2014-05-30 19:44:03 UTC (rev 61363)
@@ -271,7 +271,7 @@
                     // have to create an extra row of children faces around the
                     // hole.
                     HbrHalfedge<T> * e = f->GetFirstEdge();
-                    for (int i=0; i<f->GetNumVertices(); ++i) {
+                    for (int j=0; j<f->GetNumVertices(); ++j) {
                         assert(e);
                         if (e->GetRightFace() and (not e->GetRightFace()->IsHole())) {
 
@@ -701,7 +701,7 @@
 }
 
 template <class T, class U> void
-copyVertex( T & dest, U const & src ) {
+copyVertex( T & /* dest */, U const & /* src */ ) {
 }
 
 template <class T> void
@@ -760,7 +760,7 @@
         FarPatchTablesFactory<T> factory(GetHbrMesh(), _numFaces, _remapTable);
 
         // XXXX: currently PatchGregory shader supports up to 29 valence
-        result->_patchTables = factory.Create(GetMaxLevel()+1, _maxValence, _numPtexFaces, fvarwidth);
+        result->_patchTables = factory.Create(_maxValence, _numPtexFaces, fvarwidth);
 
     } else {
         result->_patchTables = FarPatchTablesFactory<T>::Create(GetHbrMesh(), _facesList, _remapTable, _firstlevel, _patchType, _numPtexFaces, fvarwidth );

Modified: trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/patchMap.h
===================================================================
--- trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/patchMap.h	2014-05-20 21:24:22 UTC (rev 61362)
+++ trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/patchMap.h	2014-05-30 19:44:03 UTC (rev 61363)
@@ -76,7 +76,7 @@
     Handle const * FindPatch( int faceid, float u, float v ) const;
     
 private:
-    void initialize( FarPatchTables const & patchTables );
+    inline void initialize( FarPatchTables const & patchTables );
 
     // Quadtree node with 4 children
     struct QuadNode {
@@ -288,14 +288,14 @@
                 continue;
             } 
                   
-            short u = bits.GetU(),
-                  v = bits.GetV(),
-                  pdepth = bits.NonQuadRoot() ? depth-2 : depth-1,
-                  half = 1 << pdepth;
+            int u = bits.GetU(),
+                v = bits.GetV(),
+                pdepth = bits.NonQuadRoot() ? depth-2 : depth-1,
+                half = 1 << pdepth;
             
             for (unsigned char k=0; k<depth; ++k) {
 
-                short delta = half >> 1;
+                int delta = half >> 1;
                 
                 int quadrant = resolveQuadrant(half, u, v);
                 assert(quadrant>=0);

Modified: trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/patchParam.h
===================================================================
--- trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/patchParam.h	2014-05-20 21:24:22 UTC (rev 61362)
+++ trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/patchParam.h	2014-05-30 19:44:03 UTC (rev 61363)
@@ -79,14 +79,14 @@
 
         /// \brief Returns the log2 value of the u parameter at the top left corner of
         /// the patch
-        unsigned short GetU() const { return (field >> 17) & 0x3ff; }
+        unsigned short GetU() const { return (unsigned short)((field >> 17) & 0x3ff); }
 
         /// \brief Returns the log2 value of the v parameter at the top left corner of
         /// the patch
-        unsigned short GetV() const { return (field >> 7) & 0x3ff; }
+        unsigned short GetV() const { return (unsigned short)((field >> 7) & 0x3ff); }
 
         /// \brief Returns the rotation of the patch (the number of CCW parameter winding)
-        unsigned char GetRotation() const { return (field >> 5) & 0x3; }
+        unsigned char GetRotation() const { return (unsigned char)((field >> 5) & 0x3); }
 
         /// \brief True if the parent coarse face is a non-quad
         bool NonQuadRoot() const { return (field >> 4) & 0x1; }
@@ -96,7 +96,7 @@
         float GetParamFraction() const;
 
         /// \brief Returns the level of subdivision of the patch 
-        unsigned char GetDepth() const { return (field & 0xf); }
+        unsigned char GetDepth() const { return  (unsigned char)(field & 0xf); }
 
         /// The (u,v) pair is normalized to this sub-parametric space. 
         ///

Modified: trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/patchTables.h
===================================================================
--- trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/patchTables.h	2014-05-20 21:24:22 UTC (rev 61362)
+++ trunk/lib/win64_vc12/opensubdiv/include/opensubdiv/far/patchTables.h	2014-05-30 19:44:03 UTC (rev 61363)
@@ -75,7 +75,7 @@
         PATTERN1,
         PATTERN2,
         PATTERN3,
-        PATTERN4,
+        PATTERN4
     };
 
     /// \brief Describes the type of a patch
@@ -123,12 +123,12 @@
 
         /// \brief Returns the rotation of the patch (4 rotations)
         unsigned char GetRotation() const {
-            return _rotation;
+            return (unsigned char)_rotation;
         }
 
         /// \brief Returns the number of control vertices expected for a patch of the
         /// type described
-        static short GetNumControlVertices( Type t );
+        static inline short GetNumControlVertices( Type t );
 
         /// \brief Returns the number of control vertices expected for a patch of the
         /// type described
@@ -137,13 +137,13 @@
         }
 
         /// Returns a vector of all the legal patch descriptors
-        static std::vector<Descriptor> const & GetAllValidDescriptors();
+        static inline std::vector<Descriptor> const & GetAllValidDescriptors();
 
         /// \brief Allows ordering of patches by type
-        bool operator < ( Descriptor const other ) const;
+        inline bool operator < ( Descriptor const other ) const;
 
         /// \brief True if the descriptors are identical
-        bool operator == ( Descriptor const other ) const;
+        inline bool operator == ( Descriptor const other ) const;
 
         /// \brief Descriptor Iterator
         /// Iterates through the patches in the following preset order
@@ -178,7 +178,7 @@
 
         enum PrimType {
             ANY,
-            FEATURE_ADAPTIVE_CATMARK,
+            FEATURE_ADAPTIVE_CATMARK
         };
 
         /// \brief Returns a patch type iterator
@@ -235,19 +235,19 @@
 
             /// \brief Constructor
             ///
             /// @param vertIndex        absolute index to the first control vertex
             ///                         of the first patch in the PTable
             ///
             /// @param patchIndex       absolute index of the first patch in the
             ///                         array
             ///
             /// @param npatches         number of patches in the array
             ///
             /// @param quadOffsetIndex  absolute index of the first quad offset
             ///                         entry
             ///
-            ArrayRange( unsigned int vertIndex, unsigned int patchIndex, unsigned int npatches, unsigned int quadOffsetIndex ) :
-                vertIndex(vertIndex), patchIndex(patchIndex), npatches(npatches), quadOffsetIndex(quadOffsetIndex) { }
+            ArrayRange( unsigned int ivertIndex, unsigned int ipatchIndex, unsigned int inpatches, unsigned int iquadOffsetIndex ) :
+                vertIndex(ivertIndex), patchIndex(ipatchIndex), npatches(inpatches), quadOffsetIndex(iquadOffsetIndex) { }
 
             unsigned int vertIndex,       // absolute index to the first control vertex of the first patch in the PTable
                          patchIndex,      // absolute index of the first patch in the array
@@ -376,16 +376,16 @@
     PatchParamTable const & GetPatchParamTable() const { return _paramTable; }
 

@@ Diff output truncated at 10240 characters. @@
@@ -235,19 +235,19 @@
             /// \brief Constructor
             ///
-            /// @param vertIndex        absolute index to the first control vertex
-            ///                         of the first patch in the PTable
+            /// @param ivertIndex        absolute index to the first control vertex
+            ///                          of the first patch in the PTable
             ///
@@ -235,19 +235,19 @@
             ///
-            /// @param patchIndex       absolute index of the first patch in the
-            ///                         array
+            /// @param ipatchIndex       absolute index of the first patch in the
+            ///                          array
             ///
@@ -235,19 +235,19 @@
             ///
-            /// @param npatches         number of patches in the array
+            /// @param inpatches         number of patches in the array
             ///
@@ -235,19 +235,19 @@
             ///
-            /// @param quadOffsetIndex  absolute index of the first quad offset
-            ///                         entry
+            /// @param iquadOffsetIndex  absolute index of the first quad offset
+            ///                          entry
             ///



More information about the Bf-blender-cvs mailing list